==> knative-model-4.4.1-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/InMemoryChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.duck.v1alpha1.SubscribableStatus;
import io.fabric8.knative.duck.v1alpha1.SubscribableStatusFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.duck.v1alpha1.SubscribableStatusBuilder;
import io.fabric8.knative.v1.ConditionBuilder;
import javax.validation.Valid;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface InMemoryChannelStatusFluent<A extends InMemoryChannelStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public Addressable getAddress();
    public Addressable buildAddress();
    public A withAddress(Addressable address);
    public Boolean hasAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> withNewAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
    public InMemoryChannelStatusFluent.AddressNested<A> editAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddress();
    public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editCondition(int index);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editFirstCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editLastCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    
/**
 * This method has been deprecated, please use method buildSubscribablestatus instead.
 * @return The buildable object.
 */
@Deprecated public SubscribableStatus getSubscribablestatus();
    public SubscribableStatus buildSubscribablestatus();
    public A withSubscribablestatus(SubscribableStatus subscribablestatus);
    public Boolean hasSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> withNewSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> withNewSubscribablestatusLike(SubscribableStatus item);
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> editSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> editOrNewSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> editOrNewSubscribablestatusLike(SubscribableStatus item);

    public interface AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AddressableFluent<InMemoryChannelStatusFluent.AddressNested<N>>{

        
    public N and();    public N endAddress();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<InMemoryChannelStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface SubscribablestatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscribableStatusFluent<InMemoryChannelStatusFluent.SubscribablestatusNested<N>>{

        
    public N and();    public N endSubscribablestatus();
}


}

==> knative-model-4.6.4-sources.jar: annotations/io/fabric8/knative/messaging/v1alpha1/InMemoryChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.duck.v1alpha1.SubscribableStatus;
import io.fabric8.knative.duck.v1alpha1.SubscribableStatusFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.duck.v1alpha1.SubscribableStatusBuilder;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface InMemoryChannelStatusFluent<A extends InMemoryChannelStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.duck.v1alpha1.Addressable getAddress();
    public io.fabric8.knative.duck.v1alpha1.Addressable buildAddress();
    public A withAddress(io.fabric8.knative.duck.v1alpha1.Addressable address);
    public Boolean hasAddress();
    public InMemoryChannelStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
    public InMemoryChannelStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public InMemoryChannelStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
    public InMemoryChannelStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
    public InMemoryChannelStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editCondition(int index);
    public InMemoryChannelStatusFluent.ConditionsNested<A> editFirstCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editLastCondition();
    public InMemoryChannelStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    
/**
 * This method has been deprecated, please use method buildSubscribablestatus instead.
 * @return The buildable object.
 */
@Deprecated public SubscribableStatus getSubscribablestatus();
    public SubscribableStatus buildSubscribablestatus();
    public A withSubscribablestatus(SubscribableStatus subscribablestatus);
    public Boolean hasSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> withNewSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> withNewSubscribablestatusLike(SubscribableStatus item);
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> editSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> editOrNewSubscribablestatus();
    public InMemoryChannelStatusFluent.SubscribablestatusNested<A> editOrNewSubscribablestatusLike(SubscribableStatus item);

    public interface V1alpha1AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1alpha1.AddressableFluent<InMemoryChannelStatusFluent.V1alpha1AddressNested<N>>{

        
    public N and();    public N endV1alpha1Address();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<InMemoryChannelStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface SubscribablestatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SubscribableStatusFluent<InMemoryChannelStatusFluent.SubscribablestatusNested<N>>{

        
    public N and();    public N endSubscribablestatus();
}


}
